@@ -1,13 +1,17 @@
 # This file contains functions to call phyclust_find_consensus() in C.
 
-find.consensus <- function(X, code.type = .code.type[1], with.missing = FALSE){
+find.consensus <- function(X, code.type = .code.type[1], with.gap = FALSE){
+  if(! is.matrix(X)){
+    stop("X is not a matrix.")
+  }
+
   code.type <- which(code.type == .code.type) - 1
 
   ret <- .Call("R_phyclust_find_consensus",
                as.integer(nrow(X)),
                as.integer(ncol(X)),
                as.integer(code.type),
-               as.integer(with.missing),
+               as.integer(with.gap),
                as.integer(t(X)),
                PACKAGE = "phyclust")
   ret
